
import java.awt.BorderLayout;
import javax.swing.JFrame;
import javax.swing.JMenuBar;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JLabel;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Color;
import javax.swing.JOptionPane;

/**
 *
 * @author Lubos Pavlicek, 31. října 2011
 */
public class Gui {
    private JFrame okno;
    private PanelSPaskem panelSPaskem;
    private IHra [] hry;
    private JLabel jmenoHryLabel;
    private static final Color KRAJE_POZADI_COLOR = new Color(0x05, 0x2C, 0x6E);

    public Gui (IHra ... hry) {
        this.hry = hry;
        okno = new JFrame();
        okno.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        Color panelPozadiColor = new Color(0x80, 0xEA, 0x69);
        
        panelSPaskem = new PanelSPaskem(hry[0]);
        panelSPaskem.setOpaque(true);
        panelSPaskem.setBackground(panelPozadiColor);
        okno.add(panelSPaskem, BorderLayout.CENTER);
        
        jmenoHryLabel = new JLabel(hry[0].getNazev());
        jmenoHryLabel.setHorizontalAlignment(JLabel.CENTER);
        jmenoHryLabel.setOpaque(true);
        jmenoHryLabel.setBackground(KRAJE_POZADI_COLOR);
        jmenoHryLabel.setForeground(Color.WHITE);
        okno.add(jmenoHryLabel, BorderLayout.SOUTH);
        
        okno.setJMenuBar(initMenu());

        okno.pack();
    }

    public void setVisible(boolean visible) {
        okno.setVisible(visible);
    }
    
    private JMenuBar initMenu() {
        JMenuBar lista = new JMenuBar();
        JMenu varianty = new JMenu("Varianty");
        JMenu oHre = new JMenu("O hře");
        
        for (int i=0; i < hry.length; i++) {
            JMenuItem polMenu = new JMenuItem((i + 1) + ". " + hry[i].getNazev());
            final int poradi = i;
            polMenu.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent udalost) {
                    try {
                        IHra novaHra = hry[poradi].getClass().newInstance();
                        jmenoHryLabel.setText(novaHra.getNazev());
                        panelSPaskem.setHra(novaHra);
                    }
                    catch (InstantiationException ex) {
                        JOptionPane.showMessageDialog(okno,
                            "Nepodařilo se vytvořit instanci třídy "
                            + hry[poradi].getClass().getSimpleName()
                            + "Pravděpodobně nemá konstruktor bez parametrů "
                            + ex.getMessage(),
                            "Instantiation Exception",
                            JOptionPane.ERROR_MESSAGE);

                    }
                    catch (IllegalAccessException ex) {
                        JOptionPane.showMessageDialog(okno,
                            "Nepodařilo se vytvořit instanci třídy "
                            + hry[poradi].getClass().getSimpleName()
                            + "Pravděpodobně není dostupný soubor .class "
                            + ex.getMessage(),
                            "IllegalAccess Exception",
                            JOptionPane.ERROR_MESSAGE);

                    }
                }
            });
            varianty.add(polMenu);
            JMenuItem oHreItem = new JMenuItem((i + 1) + ". " + hry[i].getNazev());
            oHreItem.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent udalost) {
                    JOptionPane.showMessageDialog(okno,
                        hry[poradi].getOHre(),
                        "varianta " +hry[poradi].getNazev(),
                        JOptionPane.INFORMATION_MESSAGE);                        
                }
            });
            oHre.add(oHreItem);
        }
        JMenuItem konecHryItem = new JMenuItem("Konec");
        konecHryItem.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent udalost) {
                System.exit(0);
            }
        });
        varianty.addSeparator();
        varianty.add(konecHryItem);
        
        lista.add(varianty);
        lista.add(javax.swing.Box.createGlue());
        lista.add(oHre);
        return lista;
    }

}
