
/**
 * Rozhraní předepisuje metody pro třídu, která řídí logiku hry.
 *
 * @author Lubos Pavlicek, 31. října 2011
 */
public interface IHra {

    /**
     * metoda vrací název pravidel (implementace). Tento název se zobrazí v menu ve hře.
     * 
     * @return nazev pravidel
     */
    public String getNazev();
    
    /**
     * metoda vrací text, který se zobrazí jako nápoveda k implementaci. Obvykle je obsahem
     * přehled pravidel.
     * 
     * @return popis pravidel
     */
    public String getOHre();

    /**
     * metoda vrací aktuální pole mincí
     *
     * @return   pole mincí, prvky jsou buď hodnoty null (na políčku nic není),
     *           nebo instance třídy Mince,
     *
     */
    public Mince[] getPoleMinci();

    /**
     * Metoda vrací true, pokud je konec hry.
     *
     * @return   true, pokud je konec hry
     */
    public boolean konecHry();

    /**
     * Metoda vrací text, který se zobrazí na konci hry. Obvykle by v něm mělo
     * být napsáno, kdo vyhrál - zda hráč či počítač.
     *
     * @return závěrečný text
     */
    public String zaverecnyText();

    /**
     * Metoda zkontroluje tah hráče. Pokud je přípustný, vrátí true, jinak vrací false.
     * Při implementaci se ve hře též obvykle přesune mince v poli.
     *
     * @param tah Tah hráče, tj. z jaké pozice přesouvá minci na jakou pozici.
     * @return    true, pokud je tah přípustný, jinak false.
     */
    public boolean tahHrace(Tah tah);

    /**
     * Metoda vrací tah počítače.
     *
     * @return  tah počítače, tj. za jaké pozice přesouvá počítač minci na jakou pozici.
     */
    public Tah tahPocitace();
}
