
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Point;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.net.URL;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JOptionPane;
import javax.swing.JPanel;

/**
 * Panel zobrazující pole mincí.
 *
 * @author Lubos Pavlicek, 31. října 2011
 */
public class PanelSPaskem extends JPanel {
    private ImageIcon poleMinciIcon;
    private IHra hra;
    
    private static final int OKRAJ = 3;

    private Point [] pozice = {
        new Point(  7+OKRAJ,  3+OKRAJ),
        new Point( 52+OKRAJ,  3+OKRAJ),
        new Point( 96+OKRAJ,  3+OKRAJ),
        new Point(140+OKRAJ,  3+OKRAJ),
        new Point(183+OKRAJ,  3+OKRAJ),
        new Point(183+OKRAJ, 38+OKRAJ),
        new Point(183+OKRAJ, 72+OKRAJ),
        new Point(183+OKRAJ,106+OKRAJ),
        new Point(140+OKRAJ,106+OKRAJ),
        new Point( 96+OKRAJ,106+OKRAJ),
        new Point( 52+OKRAJ,106+OKRAJ),
        new Point(  7+OKRAJ,106+OKRAJ),
        new Point(  7+OKRAJ,141+OKRAJ),
        new Point(  7+OKRAJ,176+OKRAJ),
        new Point(  7+OKRAJ,211+OKRAJ),
        new Point( 53+OKRAJ,212+OKRAJ),
        new Point( 98+OKRAJ,212+OKRAJ),
        new Point(143+OKRAJ,212+OKRAJ),
        new Point(143+OKRAJ,246+OKRAJ),
        new Point(143+OKRAJ,291+OKRAJ),
    };

    private int presouvanaPuvodniPozice = -1;
    private Mince presouvanaTyp;
    private int presouvanaX;
    private int presouvanaY;
    private Mince[] poleMinci;

    public PanelSPaskem (IHra hra) {
        this.hra = hra;
        URL url = this.getClass().getResource("/obrazky/pole_minci.png");
        if (url == null) {
            System.out.println("nenalezen obrazek pole_minci.png");
        }
        else {
            poleMinciIcon = new ImageIcon(url);
        }
        this.setPreferredSize(new Dimension(poleMinciIcon.getIconWidth()+OKRAJ+OKRAJ, 
                                    poleMinciIcon.getIconHeight()+OKRAJ+OKRAJ));
        this.addMouseMotionListener(new OvladacMysi2());
        this.addMouseListener(new OvladacMysi1());
        poleMinci=hra.getPoleMinci().clone();
        if (poleMinci.length != pozice.length) {
            throw new IllegalStateException("metoda getPoleMinci() vrátila pole chybné délky ("
                    + poleMinci.length + "), správná délka je "+pozice.length);
        }
    }
    
    public void setHra(IHra hra) {
        poleMinci=hra.getPoleMinci().clone();
        if (poleMinci.length != pozice.length) {
            throw new IllegalStateException("metoda getPoleMinci() vrátila pole chybné délky ("
                    + poleMinci.length + "), správná délka je "+pozice.length);
        }
        this.hra = hra;
        repaint();
    }

    @Override
    protected void paintComponent(Graphics g) {
        super.paintComponent(g);
        if (poleMinciIcon != null) {
            poleMinciIcon.paintIcon(this, g, OKRAJ, OKRAJ);
        }
        for (int i=0; i< pozice.length; i++) {
            if (poleMinci[i] != null) {
                poleMinci[i].getIcon().paintIcon(this, g, pozice[i].x,
                        pozice[i].y);
            }
        }
        if (presouvanaTyp != null) {
            presouvanaTyp.getIcon().paintIcon(this, g, presouvanaX-13,
                        presouvanaY-13);
        }
    }

    /**
     * pokud je konec hry, tak se zobrazí závěrečný text.
     */
    private void testKonce() {
        if (hra.konecHry()) {
            JOptionPane.showMessageDialog(this, hra.zaverecnyText());
            System.exit(0);
            // TODO předělat ukončení hry na restart
        }
    }

    private void hraPocitace() {
        this.repaint();
        Tah tah = hra.tahPocitace();
        // TODO simulace tahu pocitace
        poleMinci = hra.getPoleMinci().clone();
        this.repaint();
    }

    /**
     * Ovladač pro události myši nad
     */
    private class OvladacMysi1 implements MouseListener {

        @Override
        public void mouseClicked(MouseEvent e) {
            return;
        }

        @Override
        public void mousePressed(MouseEvent e) {
            for (int i=0; i< pozice.length; i++) {
                if (e.getX() >= pozice[i].x &&
                        e.getX() <= pozice[i].x + 30 &&
                        e.getY() >= pozice[i].y &&
                        e.getY() <= pozice[i].y + 30) {
                    poleMinci = hra.getPoleMinci().clone();
                    presouvanaTyp=poleMinci[i];
                    presouvanaX=e.getX();
                    presouvanaY=e.getY();
                    presouvanaPuvodniPozice=i;
                    poleMinci[i]=null;
                }
            }

        }

        @Override
        public void mouseReleased(MouseEvent e) {
            for (int i=0; i< pozice.length; i++) {
                if (e.getX() >= pozice[i].x &&
                        e.getX() <= pozice[i].x + 30 &&
                        e.getY() >= pozice[i].y &&
                        e.getY() <= pozice[i].y + 30) {
                    Tah tah = new Tah(presouvanaPuvodniPozice, i);

                    if (hra.tahHrace(tah)) {
                        testKonce();
                        hraPocitace();
                        testKonce();
                    }
                    else {
                        JOptionPane.showMessageDialog(null,
                                "tah z pozice " + presouvanaPuvodniPozice
                                + " na pozici " + i + " není přípustný",
                                "nepřípustný tah", JOptionPane.ERROR_MESSAGE);
                    }
                }
            }
            presouvanaTyp = null;
            poleMinci = hra.getPoleMinci().clone();
            e.getComponent().repaint();
        }

        @Override
        public void mouseEntered(MouseEvent e) {
            return;
        }

        @Override
        public void mouseExited(MouseEvent e) {
            return;
        }
    }

    /**
     * Ovladač myši pro události MouseMotionListener, tj. pro vytváření
     * animace přesunu.
     */
    private class OvladacMysi2 implements MouseMotionListener {
        @Override
        public void mouseDragged(MouseEvent e) {
            presouvanaX = e.getX();
            presouvanaY = e.getY();
            e.getComponent().repaint();
        }

        @Override
        public void mouseMoved(MouseEvent e) {
            return;
        }
    }

}
